@@ -1,6 +1,6 @@
 __productname__ = "analytix"
-__version__ = "0.1.0"
-__description__ = "analytix is a simple yet powerful API wrapper to make getting analytical information from your favourite services easier than ever."
+__version__ = "1.0.0"
+__description__ = "A simple yet powerful API wrapper to make getting analytical information from the YouTube Analytics API easier than ever."
 __url__ = "https://github.com/parafoxia/analytix"
 __docs__ = "https://analytix.readthedocs.io/en/latest/"
 __author__ = "Ethan Henderson"
